@@ -1,10 +1,10 @@
 #' Projection Pursuit Random Forest
 #'
 #'\code{PPforest} implements a random forest using projection pursuit trees algorithm (based on PPtreeViz package).
-#' @usage PPforest(data, class, std = TRUE, size.tr, m, PPmethod, size.p,
+#' @usage PPforest(data, y, std = 'scale', size.tr, m, PPmethod, size.p,
 #'  lambda = .1, parallel = FALSE, cores = 2, rule = 1)
 #' @param data Data frame with the complete data set.
-#' @param class A character with the name of the class variable.
+#' @param y A character with the name of the response variable.
 #' @param std if TRUE standardize the data set, needed to compute global importance measure. 
 #' @param size.tr is the size proportion of the training if we want to split the data in training and test.
 #' @param m is the number of bootstrap replicates, this corresponds with the number of trees to grow. To ensure that each observation is predicted a few times we have to select this number no too small. \code{m = 500} is by default.
@@ -32,49 +32,102 @@
 #' \item{call}{the original call to \code{PPforest}.}
 #' \item{train}{is the training data based on \code{size.tr} sample proportion}
 #' \item{test}{is the test data based on \code{1-size.tr} sample proportion}
-#'@references Natalia da Silva, Dianne Cook & Eun-Kyung Lee (2021) 
-#'A Projection Pursuit Forest Algorithm for Supervised Classification, 
-#'Journal of Computational and Graphical Statistics,
-#' DOI: 10.1080/10618600.2020.1870480
+#'@references da Silva, N., Cook, D., & Lee, E. K. (2021). A projection pursuit forest 
+#'algorithm for supervised classification. Journal of Computational and Graphical Statistics,
+#' 30(4), 1168-1180.
 #' @export
 #' @examples
 #' #crab example with all the observations used as training
-#' 
-#'pprf.crab <- PPforest(data = crab, class = 'Type',
-#'  std = FALSE, size.tr = 1, m = 200, size.p = .5, 
-#'  PPmethod = 'LDA' , parallel = TRUE, cores = 2, rule=1)
+#' set.seed(123)
+#' pprf.crab <- PPforest(data = crab, y = 'Type',
+#'  std = 'no', size.tr = 0.8, m = 100, size.p = 1, 
+#'  PPmethod = 'LDA' , parallel = TRUE, cores = 2, rule = 1)
 #' pprf.crab
 #' 
-PPforest <- function(data, class, std = TRUE, size.tr = 2/3, m = 500, PPmethod, size.p, lambda = 0.1, 
+PPforest <- function(data, y, std = 'scale', size.tr = 2/3, m = 500, PPmethod, size.p, lambda = 0.1, 
     parallel = FALSE, cores = 2, rule = 1) {
-    
+  
     Var1 <- NULL
     tree <- NULL
     pred <- NULL
     id <- NULL
 
-    if (std) {
-        dataux <- data %>% dplyr::select(-(!!class)) %>% apply(2, FUN = scale) %>% tibble::as_tibble()
-        data <- data.frame(data[, class], dataux)
-        colnames(data)[1] <- class
-    }
-    
-    clnum <- as.numeric(as.factor(data[, class]))
-    tr.index <- trainfn(as.matrix(clnum), as.matrix(data[, setdiff(colnames(data), class)]), 
-        sizetr = size.tr) + 1
+    cllev <- levels(as.factor(data[, y]))
+    clnum <- as.numeric(as.factor(data[, y]))
+    tr.index <- trainfn(as.matrix(clnum), as.matrix(data[, setdiff(colnames(data), y)]), 
+                        sizetr = size.tr) + 1
     tr.index <- as.vector(tr.index)
     train <- data %>% dplyr::slice(tr.index)
+    test <- data[-tr.index, ] 
+   
     
     type = "Classification"
-    var.sel <- round((ncol(train) - 1) * size.p)
+    dataux <- NULL
+    mincol <- NULL
+    maxmincol<- NULL
+    train_mean <- NULL
+    train_sd <- NULL
     
-    outputaux <- baggtree(data = train, class = class, m = m, PPmethod = PPmethod, lambda = lambda, 
+    # Variable scaling.
+    if (std != "no") {
+      
+      if (std == "min-max") {
+        dataux <- train %>% 
+          dplyr::select(-(!!y)) |>  tibble::as_tibble()
+        mincol <- dataux |> apply( 2, min)
+        maxmincol <- dataux |> apply(2, function(x) {
+          max(x) - min(x)
+        })
+      }
+      if (std == "quant") {
+        dataux <- train %>% 
+          dplyr::select(-(!!y)) |>  tibble::as_tibble()
+        mincol <- dataux |> apply( 2, stats::quantile, 0.05) 
+        maxmincol <- dataux |> apply(2, function(x) {
+          stats::quantile(x, 0.95) - stats::quantile(x, 0.05)
+        }) 
+      }
+    
+      if (std == 'scale') {
+        dataux <- scale(train |> dplyr::select(-(!!y)) )
+        train_mean <- attr( dataux, "scaled:center")
+        train_sd <- attr( dataux, "scaled:scale")
+    }
+    if(std %in% c('min-max', 'quant')) {
+    trainscale <- (dataux - matrix(mincol, nrow(dataux), ncol(dataux), byrow = T)) / matrix(maxmincol, nrow(dataux), ncol(dataux), byrow = T)
+    train <- data.frame(train[, y], trainscale)
+    colnames(train)[1] <- y
+    if (dim(test)[1] != 0){
+      testscale <- test |> dplyr::select(-(!!y)) |> as.matrix()
+      testscale <- (testscale  - matrix(mincol, nrow(testscale), ncol(testscale), byrow = T)) / matrix(maxmincol, nrow(testscale), ncol(testscale), byrow = T)
+      test <-  data.frame(test[, y], testscale)
+      colnames(test)[1] <- y
+      }
+    
+    }else{
+      train <- data.frame(train[, y], dataux)
+      colnames(train)[1] <- y
+      if (dim(test)[1] != 0){
+        testscale <- test |> 
+          dplyr::select(-(!!y)) |> as.matrix() 
+        testscale <- sweep(testscale, 2, train_mean, "-")
+        testscale <- sweep( testscale,2, train_sd, "/")
+        test <- data.frame(test[, y], testscale)
+        colnames(test)[1] <- y
+        
+      }
+      }
+    }  
+    
+  
+    outputaux <- baggtree(data = train, y = y, m = m, PPmethod = PPmethod, lambda = lambda, 
         size.p = size.p, parallel = parallel, cores = cores)
     
+    var.sel <- sum(outputaux[[1]][[1]]$projbest.node[1,]!=0)
     output <- lapply(outputaux, function(x) x[[1]])
     
     data.b <- lapply(outputaux, function(x) x[[2]])
-    pred.tr <- trees_pred(outputaux, xnew = dplyr::select(train, -(!!class)), parallel, cores = cores, rule = rule)
+    pred.tr <- trees_pred(outputaux, xnew = dplyr::select(train, -(!!y)), parallel, cores = cores, rule = rule)
     
     expand.grid.ef <- function(seq1, seq2) {
         data.frame(a = rep.int(seq1, length(seq2)), b = rep.int(seq2, rep.int(length(seq1), 
@@ -92,25 +145,26 @@ PPforest <- function(data, class, std = TRUE, size.tr = 2/3, m = 500, PPmethod,
     oob.pred <- mvote.oob[, length(unique(clnum)) + 1]
     
     votes <- mvote.oob[, -(length(unique(clnum)) + 1)]
-    colnames(votes) <- levels(train[, class])
+    colnames(votes) <- levels(train[, y])
     
     vote.matrix.prop <- votes/rowSums(votes)
     
-    oob.error <- 1 - sum(diag(table(oob.pred, unlist(train[, class]))))/length(unlist(train[, 
-        class]))
+    oob.error <- 1 - sum(diag(table(oob.pred, unlist(train[, y]))))/length(unlist(train[, 
+        y]))
     
     oob.err.tree <- ooberrortree(pred.tr$predtree, oob.obs, as.numeric(as.factor(unlist(train[, 
-        class]))), m)
+        y]))), m)
     
   
-    error.tr <- 1 - sum(as.numeric(as.factor(unlist(train[, class]))) == pred.tr$predforest)/length(pred.tr$predforest)
-    test <- data[-tr.index, ] %>% dplyr::select(-(!!class)) 
+    error.tr <- 1 - sum(as.numeric(as.factor(unlist(train[, y]))) == pred.tr$predforest)/length(pred.tr$predforest)
+   
     
-    if (dim(test)[1] != 0) {
-        pred.test <- trees_pred(outputaux, xnew = test, parallel, cores = cores, rule = rule)
-        error.test <- 1 - sum(as.numeric(as.factor(data[-tr.index, class])) == pred.test[[2]])/length(pred.test[[2]])
-        pred.test = as.factor(pred.test[[2]])
-        levels(pred.test) <- levels(unlist(train[, class]))
+    if (dim(test)[1] != 0){
+      
+        pred.test <- trees_pred(outputaux, xnew = dplyr::select(test, -(!!y)), parallel, cores = cores, rule = rule)
+        error.test <- 1 - sum(as.numeric(as.factor(test[, y])) == pred.test[[2]])/length(pred.test[[2]])
+         pred.test = as.factor(pred.test[[2]])
+        levels(pred.test) <- levels(as.factor(train[, y]))
     } else {
         pred.test <- NULL
         error.test <- NULL
@@ -118,21 +172,21 @@ PPforest <- function(data, class, std = TRUE, size.tr = 2/3, m = 500, PPmethod,
     }
     
     oob.pred <- as.factor(oob.pred)
-    if (is.factor(unlist(train[, class]))) {
-        levels(oob.pred) <- levels(unlist(train[, class]))
+    if (is.factor(unlist(train[, y]))) {
+        levels(oob.pred) <- levels(unlist(train[, y]))
     } else {
-        levels(oob.pred) <- levels(as.factor(unlist(train[, class])))
+        levels(oob.pred) <- levels(as.factor(unlist(train[, y])))
     }
     
     prediction.training <- as.factor(pred.tr$predforest)
-    if (is.factor(unlist(train[, class]))) {
-        levels(prediction.training) <- levels(unlist(train[, class]))
+    if (is.factor(unlist(train[, y]))) {
+        levels(prediction.training) <- levels(unlist(train[, y]))
     } else {
-        levels(prediction.training) <- levels(as.factor(unlist(train[, class])))
+        levels(prediction.training) <- levels(as.factor(unlist(train[, y])))
     }
     
     
-    tab.tr <- table(Observed = unlist(train[, class]), Predicted = oob.pred)
+    tab.tr <- table(Observed = unlist(train[, y]), Predicted = oob.pred)
     
     class.error <- 1 - diag(tab.tr)/((stats::addmargins(tab.tr, 2))[, "Sum"])
     confusion <- cbind(tab.tr, class.error = round(class.error, 2))
@@ -141,8 +195,8 @@ PPforest <- function(data, class, std = TRUE, size.tr = 2/3, m = 500, PPmethod,
         error.test = error.test, oob.error.forest = oob.error, oob.error.tree = oob.err.tree,
         boot.samp = data.b, output.trees = output, proximity = proximity, votes = vote.matrix.prop,
         prediction.oob = oob.pred, n.tree = m, n.var = var.sel, type = "Classification", confusion = confusion,
-        call = match.call(), train = train, test = test, vote.mat = pred.tr$predtree, class.var = class,
-        oob.obs = oob.obs)
+        call = match.call(), train = train, test = test, vote.mat = pred.tr$predtree, vote.mat_cl= cllev, class.var = y,
+        oob.obs = oob.obs, std = std, dataux = dataux, mincol = mincol, maxmincol = maxmincol, train_mean = train_mean, train_sd = train_sd)
   
     
     class(results) <- "PPforest"
